@@ -1,20 +1,22 @@
-#' @importFrom vmd vmd
+#' @importFrom VMDecomp vmd
 #' @importFrom forecast nnetar forecast
 #' @importFrom utils head tail
 #' @importFrom graphics plot
 #' @importFrom stats as.ts ts
 #' @export
 #'
-VMDARIMA <- function (data, stepahead=10, nIMF=4, alpha=2000, tau=0)
+VMDARIMA <- function(data, stepahead=10, nIMF=4, alpha=2000, tau=0, D=FALSE)
 {
-  v<- vmd(data , alpha=2000, tau=0, K=nIMF, orderModes=TRUE)
-  AllIMF<-v$as.data.frame()
+  data <- ts(data)
+  data<- as.vector(data)
+  v<- vmd(data , alpha=2000, tau=0, K=nIMF, DC=D, init=1, tol = 1e-6)
+  AllIMF<-v$u
   data_trn <- ts(head(data, round(length(data) - stepahead)))
   data_test <- ts(tail(data, stepahead))
   IMF_trn <- AllIMF[-c(((length(data) - stepahead) + 1):length(data)),
   ]
   Fcast_AllIMF <- NULL
-  for (AllIMF in 3:(ncol(IMF_trn)-1)) {
+  for (AllIMF in 1:(ncol(IMF_trn))) {
     IndIMF <- NULL
     IndIMF <- IMF_trn[, AllIMF]
     VMDARIMAFit <- forecast::auto.arima(as.ts(IndIMF))
@@ -26,8 +28,7 @@ VMDARIMA <- function (data, stepahead=10, nIMF=4, alpha=2000, tau=0)
   MAE_VMDARIMA = mean(abs(data_test - FinalVMDARIMA_fcast))
   MAPE_VMDARIMA = mean(abs(data_test - FinalVMDARIMA_fcast)/data_test)
   RMSE_VMDARIMA = sqrt(mean((data_test - FinalVMDARIMA_fcast)^2))
-  AllIMF_plots <- plot(v)
-  return(list(AllIMF = AllIMF, AllIMF_plots = AllIMF_plots, data_test = data_test,
+  return(list(AllIMF = AllIMF, data_test = data_test,
               AllIMF_forecast = Fcast_AllIMF, FinalVMDARIMA_forecast = FinalVMDARIMA_fcast,
               MAE_VMDARIMA = MAE_VMDARIMA, MAPE_VMDARIMA = MAPE_VMDARIMA,
               RMSE_VMDARIMA = RMSE_VMDARIMA ))
